==> hadoop-client-api-3.2.4-sources.jar: org/apache/hadoop/hdfs/protocol/XAttrNotFoundException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.shaded.org.apache.hadoop.hdfs.protocol;

import java.org.apache.hadoop.shaded.io.IOException;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability;

/**
 * The exception that happens when you ask to get a non existing XAttr.
 */
@InterfaceAudience.Private
@InterfaceStability.Evolving
public class XAttrNotFoundException extends IOException {
  private static final long serialVersionUID = -6506239904158794057L;
  public static final String DEFAULT_EXCEPTION_MSG =
      "At least one of the attributes provided was not found.";
  public XAttrNotFoundException() {
    this(DEFAULT_EXCEPTION_MSG);
  }
  public XAttrNotFoundException(String msg) {
    super(msg);
  }
}

==> hadoop-client-api-3.4.0-sources.jar: org/apache/hadoop/hdfs/protocol/XAttrNotFoundException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.shaded.org.apache.hadoop.hdfs.protocol;

import java.io.IOException;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability;

/**
 * The exception that happens when you ask to get a non existing XAttr.
 */
@InterfaceAudience.Private
@InterfaceStability.Evolving
public class XAttrNotFoundException extends IOException {
  private static final long serialVersionUID = -6506239904158794057L;
  public static final String DEFAULT_EXCEPTION_MSG =
      "At least one of the attributes provided was not found.";
  public XAttrNotFoundException() {
    this(DEFAULT_EXCEPTION_MSG);
  }
  public XAttrNotFoundException(String msg) {
    super(msg);
  }
}
